RIFT
==========

Rapid inference via Iterative FiTting: this algorithm provides a framework for efficient, highly-parallelized parameter inference for GW sources.
   
.. automodule:: RIFT
    :members:

.. toctree::
   :maxdepth: 20
   :caption: Contents:

   overview
   installation
   using-pipeline
   examples-ini
   examples-noini
   getting-data
   osg
   injections
   plotting
   hyperpipe
   troubleshooting






